@@ -23,12 +23,6 @@ class SimpleLogger(Logger):
         self.time_at_last_move = time.process_time()
 
     def apply(self, board, player1, player2):
-        if board.is_game_over():
-            # The winner must be P1 if it is P1's turn (hence P1 just ate a piece from P2) but P2 still has
-            # available moves (otherwise it would imply that the game ended not because P2 ran out of pieces
-            # but because P1 ran out of moves)
-            self.winner = board.P1 if (board.player_turn) and board.get_possible_next_moves() else board.P2
-
         self.current_turn_number += 1
 
         self.board_state_history.append(copy.deepcopy(board.spots))
@@ -37,6 +31,7 @@ class SimpleLogger(Logger):
         self.time_at_last_move = time.process_time()
 
     def end(self, board, player1, player2):
+        self.winner = board.Current_Winner
         pass
 
     def exit(self, board, player1, player2):
